==> bitcoin_0.12.1.orig.tar.gz: bitcoin-0.12.1/src/qt/locale/bitcoin_es_AR.ts <==
<TS language="es_AR" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Hacé click para editar la dirección o etiqueta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiá la dirección que seleccionaste al portapapeles</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;lose</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Copiar Dirección</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Borrar de la lista la dirección seleccionada</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar los datos de la pestaña actual a un archivo</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Elegir la dirección a donde enviar las monedas (coins)</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Elegí la dirección donde recibir las monedas</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>E&amp;legir</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Direcciones de envío</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Direcciones de recepción</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Estas son tus direcciones Bitcoin para enviar pagos. Siempre chequeá el monto y la dirección de recepción antes de mandar monedas.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Estas son tus direcciones para recibir pagos. Te recomendamos que uses una dirección de recibir  para cada transacción.</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Copiar &amp;Etiqueta</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Exportar lista de direcciones</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivo separado por coma (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Falló la exportación</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Hubo un error al tratar de guardar la lista de direcciones a %1. Por favor tratá de nuevo.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de Frase de Contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Ingresar la Frase de Contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva Frase de Contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetí la nueva Frase de Contraseña</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Encriptar la billetera</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Esta operación necesita tu frase de contraseña para desbloquear tu billetera.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Desbloquear la billetera</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Esta operación necesita tu Frase de Contraseña de billetera para desencriptar la billetera.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Desencriptar la billetera</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Cambiar la Frase de Contraseña</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Confirmá la encriptación de la billetera</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Atención: Si encriptás tu billetera y perdés tu frase de contraseña, vas a &lt;b&gt;PERDER TODOS TUS BITCOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>¿Estás seguro que querés encriptar tu billetera?</translation>
    </message>
    <message>
        <source>Bitcoin Core will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>Bitcoin Core ahora se va a cerrar para terminar el proceso de encriptación. Acordate que encriptar tu billetera no te protege completamente de que algún malware que pueda infectar tu computadora te robe tus bitcoins.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>IMPORTANTE: Todos los backups que hayas hecho de tu billetera tendrían que ser reemplazados por el archivo encriptado de billetera que generaste. Por razones de seguridad, los backups anteriores del archivo de billetera no encriptado se inutilizan en el momento en que empezás a usar la nueva billetera encriptada</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Atención: Tenés puestas las mayúsculas!</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Billetera encriptada</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Ingresá una nueva frase de contraseña para la billetera.&lt;br/&gt;Por favor, fijate de usar una frase de contraseña de &lt;b&gt;diez o más caracteres aleatorios&lt;/b&gt;, o de &lt;b&gt;ocho o más palabras&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Ingresá la frase de contraseña  vieja y la nueva para la billetera.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Falló la encriptación de la billetera</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Falló la encriptación de la billetera por un error interno. Tu billetera no está encriptada.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Las frases de contraseña no son iguales.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Falló el desbloqueo de la billetera</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>La frase de contraseña que ingresaste para desencriptar la billetera es incorrecta.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Falló la desencriptación de la billetera</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>ClientModel</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(sin etiqueta)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Exporting Failed</source>
        <translation>Falló la exportación</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Archivo separado por coma (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Dirección</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar los datos de la pestaña actual a un archivo</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.13.1.tar.gz: bitcoin-0.13.1/src/qt/locale/bitcoin_es_AR.ts <==
<TS language="es_AR" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Hacé click para editar la dirección o etiqueta</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Crear una nueva dirección</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Copiá la dirección que seleccionaste al portapapeles</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>C&amp;lose</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Borrar de la lista la dirección seleccionada</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Exportar los datos de la pestaña actual a un archivo</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exportar</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Borrar</translation>
    </message>
    </context>
<context>
    <name>AddressTableModel</name>
    </context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Diálogo de Frase de Contraseña</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Ingresar la Frase de Contraseña</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nueva Frase de Contraseña</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Repetí la nueva Frase de Contraseña</translation>
    </message>
    </context>
<context>
    <name>BanTableModel</name>
    </context>
<context>
    <name>BitcoinGUI</name>
    </context>
<context>
    <name>CoinControlDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    </context>
<context>
    <name>SendCoinsDialog</name>
    </context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    </context>
<context>
    <name>TransactionView</name>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
